==> assetgraph-0.1.5.tgz: package/test/htmlEmbed-test.js <==
var vows = require('vows'),
    assert = require('assert'),
    urlTools = require('../lib/util/urlTools'),
    AssetGraph = require('../lib/AssetGraph'),
    transforms = AssetGraph.transforms,
    query = AssetGraph.query;

vows.describe('<embed src="..."> test').addBatch({
    'After loading test': {
        topic: function () {
            new AssetGraph({root: __dirname + '/htmlEmbed/'}).queue(
                transforms.loadAssets('index.html'),
                transforms.populate({
                    followRelations: function () {return false;}
                })
            ).run(this.callback);
        },
        'the graph should contain one HtmlEmbed relation': function (assetGraph) {
            assert.equal(assetGraph.findRelations({type: 'HtmlEmbed'}, true).length, 1);
        },
        'the urls of the HtmlEmbed relation should be correct': function (assetGraph) {
            assert.equal(assetGraph.findRelations({type: 'HtmlEmbed'}, true)[0]._getRawUrlString(), 'foo.swf');
        },
        'then move the index.html asset one subdir down': {
            topic: function (assetGraph) {
                assetGraph.setAssetUrl(assetGraph.findAssets({type: 'Html'})[0], urlTools.resolveUrl(assetGraph.root, 'foo/index.html'));
                return assetGraph;
            },
            'the urls of the HtmlEmbed relation should have ../ prepended': function (assetGraph) {
                assert.equal(assetGraph.findRelations({type: 'HtmlEmbed'}, true)[0]._getRawUrlString(), '../foo.swf');
            }
        }
    }
})['export'](module);

==> assetgraph-0.3.12.tgz: package/test/htmlEmbed-test.js <==
var vows = require('vows'),
    assert = require('assert'),
    urlTools = require('../lib/util/urlTools'),
    AssetGraph = require('../lib/AssetGraph'),
    transforms = AssetGraph.transforms,
    query = AssetGraph.query;

vows.describe('<embed src="..."> test').addBatch({
    'After loading test': {
        topic: function () {
            new AssetGraph({root: __dirname + '/htmlEmbed/'}).queue(
                transforms.loadAssets('index.html'),
                transforms.populate({
                    followRelations: function () {return false;}
                })
            ).run(this.callback);
        },
        'the graph should contain one HtmlEmbed relation': function (assetGraph) {
            assert.equal(assetGraph.findRelations({type: 'HtmlEmbed'}, true).length, 1);
        },
        'the urls of the HtmlEmbed relation should be correct': function (assetGraph) {
            assert.equal(assetGraph.findRelations({type: 'HtmlEmbed'}, true)[0].href, 'foo.swf');
        },
        'then move the index.html asset one subdir down': {
            topic: function (assetGraph) {
                assetGraph.findAssets({type: 'Html'})[0].url = urlTools.resolveUrl(assetGraph.root, 'foo/index.html');
                return assetGraph;
            },
            'the urls of the HtmlEmbed relation should have ../ prepended': function (assetGraph) {
                assert.equal(assetGraph.findRelations({type: 'HtmlEmbed'}, true)[0].href, '../foo.swf');
            }
        }
    }
})['export'](module);
